// ********************************************************************************************************
// <copyright file="Layers.cs" company="TopX Geo-ICT">
//     Copyright (c) 2011-2013 TopX Geo-ICT. All rights reserved.
// </copyright>
// ********************************************************************************************************
// The contents of this file are subject to the Mozilla Public License Version 1.1 (the "License"); 
// you may not use this file except in compliance with the License. You may obtain a copy of the License at 
// http:// www.mozilla.org/MPL/ 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF 
// ANY KIND, either express or implied. See the License for the specific language governing rights and 
// limitations under the License. 
// 
// The Original Code is MapWindow Open Source MeemsTools Plug-in. 
// 
// The Initial Developer of this version of the Original Code is Paul Meems.
// 
// Contributor(s): (Open source contributors should list themselves and their modifications here). 
// Change Log: 
// Date           Changed By      Notes
// 13 April 2008  Paul Meems      Inital upload the MW SVN repository
// 28 August 2009 Paul Meems      Made the code StyleCop compliant
// 5  May 2011    Paul Meems      Made changes as suggested by ReSharper   
// 09 Sept 2013   Paul Meems      Converted to a template plug-in for general use
// ********************************************************************************************************

namespace LabelRotation.Forms
{
  #region Usings

  using System;
  using System.Reflection;
  using System.Windows.Forms;
  using MapWindow.Interfaces;

  using LabelRotation.Classes;

  #endregion

  /// <summary>
  ///   This class holds all code used in this form
  /// </summary>
  public partial class Layers : Form
  {
    private Layer selectedLayerItem;

    /// <summary>
    ///   Initializes a new instance of the Layers class.
    /// </summary>
    public Layers()
    {
      this.InitializeComponent();

      // Set versionnr in statuslabel:
      this.VersionLabel.Text = @"v" + Assembly.GetExecutingAssembly().GetName().Version;

      // Fill combobox:  
      Utils.FillVisibleLayers(this.cboLayers);
    }

    /// <summary>
    ///   Index changed event of cboLayers
    /// </summary>
    /// <param name = "sender">Sender (object)</param>
    /// <param name = "e">Event arguments</param>
    private void CboLayersSelectedIndexChanged(object sender, EventArgs e)
    {
      // Get data from combobox
      // C#3.0: Implicitly Typed Local Variables and Arrays:
      this.selectedLayerItem = (Layer)this.cboLayers.SelectedItem;
      if (this.selectedLayerItem == null)
      {
        // Default values:
        this.lblName.Text = string.Empty;
        this.RotateButton.Enabled = false;
        return;
      }

      // Fill field list:
      this.lblProgress.Text = @"Select the field!";
      Utils.FillFields(this.selectedLayerItem, this.FieldList);
    }

    /// <summary>Click event</summary>
    /// <param name="sender">The sender</param>
    /// <param name="e">The event arguments</param>
    private void RotateButtonClick(object sender, EventArgs e)
    {
      this.RotateButton.Enabled = false;
      this.lblProgress.Text = @"Working ...";
      Utils.RotateLabels(this.selectedLayerItem, this.FieldList.SelectedItem.ToString());
      this.lblProgress.Text = @"Done!";
    }

    /// <summary>
    ///   Index changed event of FieldList
    /// </summary>
    /// <param name = "sender">Sender (object)</param>
    /// <param name = "e">Event arguments</param>
    private void FieldListSelectedIndexChanged(object sender, EventArgs e)
    {
      // Fill filename:
      this.lblName.Text = System.IO.Path.GetFileName(this.selectedLayerItem.FileName);

      // Enable rotate button:
      this.lblProgress.Text = @"Press the rotate button!";
      this.RotateButton.Enabled = true;
    }

    /// <summary>Form closed event</summary>
    /// <param name="sender">
    /// The sender.
    /// </param>
    /// <param name="e">
    /// The e.
    /// </param>
    private void LayersFormClosed(object sender, FormClosedEventArgs e)
    {
      Helper.RotateToolbarButton.Pressed = false;
    }
  }
}