﻿// ********************************************************************************************************
// <copyright file="Main.cs" company="TopX Geo-ICT">
//     Copyright (c) 2011-2013 TopX Geo-ICT. All rights reserved.
// </copyright>
// ********************************************************************************************************
// The contents of this file are subject to the Mozilla Public License Version 1.1 (the "License"); 
// you may not use this file except in compliance with the License. You may obtain a copy of the License at 
// http:// www.mozilla.org/MPL/ 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF 
// ANY KIND, either express or implied. See the License for the specific language governing rights and 
// limitations under the License. 
// 
// The Initial Developer of this version is Paul Meems.
// 
// Contributor(s): (Open source contributors should list themselves and their modifications here). 
// Change Log: 
// Date           Changed By      Notes
// 24 Nov 2011    Paul Meems      Inital coding
// 09 Sept 2013   Paul Meems      Converted to a template plug-in for general use
// 09 Sept 2013   Paul Meems      Start with the label rotation plug-in
// ********************************************************************************************************
namespace LabelRotation
{
  using System;
  using System.Collections.Generic;
  using System.Windows.Forms;

  using LabelRotation.Classes;
  using MapWindow.Interfaces;

  /// <summary>
  ///   This is the start of the plug-in. In here all methods of the IPlugin interface can be implemented.
  /// </summary>
  public class Main : PluginBase
  {
    /// <summary>Change this to your own address</summary>
    private const string ReportEmailaddress = "Bontepaarden@gmail.com";

    /// <summary>The stack with the toolbuttons</summary>
    private readonly Stack<string> addedToolbuttons = new Stack<string>();

    /// <summary>The stack with the menus</summary>
    private readonly Stack<string> addedMenus = new Stack<string>();

    /// <summary>The name of your button. This need to be a constant</summary>
    private const string MyButton = "Rotation";

    /// <summary>The name of the toolbar</summary>
    private string toolbarName;

    /// <summary>This event is called when a plugin is loaded or turned on in the MapWindow.</summary>
    public override void Initialize()
    {
      try
      {
        // Create toolbar:
        this.toolbarName = this.Author;
        this.CreateToolbar();

        // Initialize helper class:
        Helper.MapWin = this.App;
      }
      catch (Exception ex)
      {
        this.App.ShowErrorDialog(ex, ReportEmailaddress);
      }
    }

    /// <summary>This method is called when a plugin is unloaded. The plugin should remove all toolbars, buttons and menus that it added.</summary>
    public override void Terminate()
    {
      // Close form:
      var inputform = Utils.GetActivatedWindow<Forms.Layers>(new IntPtr(this.ParentHandle), false);
      if (inputform != null)
      {
        inputform.Close();
        inputform.Dispose();
      }

      // Remove toolbar:
      if (this.addedToolbuttons != null)
      {
        // Unloads the buttons in reverse order
        while (this.addedToolbuttons.Count > 0)
        {
          this.App.Toolbar.RemoveButton(this.addedToolbuttons.Pop());
        }

        // If all buttons are removed, remove toolbar as well:
        if (this.App.Toolbar.NumToolbarButtons(this.toolbarName) == 0)
        {
          this.App.Toolbar.RemoveToolbar(this.toolbarName);
        }
      }

      // Remove menus:
      if (this.addedMenus == null)
      {
        return;
      }

      // Unloads the menus in reverse order
      while (this.addedMenus.Count > 0)
      {
        this.App.Menus.Remove(this.addedMenus.Pop());
      }
    }

    /// <summary>Occurs when a user clicks on a toolbar button or menu item.</summary>
    /// <param name = "itemName">The name of the item clicked on.</param>
    /// <param name = "handled">Reference parameter.  Setting Handled to true prevents other plugins from receiving this event.</param>
    public override void ItemClicked(string itemName, ref bool handled)
    {
      try
      {
        switch (itemName)
        {
          case MyButton:
            handled = true;

            if (this.App.Layers.NumLayers == 0)
            {
              MessageBox.Show(@"First open some shapefile layers.");
              break;
            }

            if (!this.App.Toolbar.ButtonItem(itemName).Pressed)
            {
              // Not pressed so activate form:
              Utils.GetActivatedWindow<Forms.Layers>(new IntPtr(this.ParentHandle), true);

              this.App.Toolbar.ButtonItem(itemName).Pressed = true;
            }
            else
            {
              // Pressed so de-activate:
              this.App.Toolbar.ButtonItem(itemName).Pressed = false;
            }

            break;
        }
      }
      catch (Exception ex)
      {
        this.App.ShowErrorDialog(ex, ReportEmailaddress);
      }
    }

    /// <summary>Create the toolbar</summary>
    private void CreateToolbar()
    {
      // Add toolbar with buttons:
      var t = this.App.Toolbar;
      t.AddToolbar(this.toolbarName);

      // First button:
      var b = t.AddButton(MyButton, this.toolbarName, string.Empty, string.Empty);
      b.BeginsGroup = true;
      b.Tooltip = "Rotate the labels based on an attribute value";
      b.Category = this.toolbarName;
      b.Text = "Rotate";

      // Change the image on the button:
      // Search http://www.iconspedia.com for great images. 24*24 png are best:
      b.Picture = Properties.Resources.Rotate;

      // Save to remove it easily on terminate:
      this.addedToolbuttons.Push(MyButton);

      // Save for easy interaction:
      Helper.RotateToolbarButton = b;
    }
  }
}
